@@ -21,7 +21,7 @@ from ._common import _design_matrix, _leg_mt
 
 
 def unbalance_longwas_fixed_permutation(data_file, id, tpoint, trait, bed_file, agmat_file, var_com, permutation_lst=None,
-            snp_lst=None, tfix=None, fix=None, forder=3, aorder=3, porder=3, na_method='omit',
+            snp_lst=None, tfix=None, fix=None, forder=3, aorder=3, porder=3, na_method='omit', crank=False,
                              prefix_outfile='unbalance_longwas_fixed_permutation'):
     """
     the longitudinal GWAS for the unbalanced data treating the SNP as the time varied fixed effect.
@@ -46,6 +46,7 @@ def unbalance_longwas_fixed_permutation(data_file, id, tpoint, trait, bed_file,
     :param porder: the order of Legendre polynomials for the permanent environment effect. The default value is 3.
     :param na_method: The method to deal with missing values. The default value is 'omit'. 'omit' method will delete the
     row with missing values. 'include' method will fill the missing values with the adjacent values.
+    :param crank: force the column full rank of fixed effects. Default is False.
     :param prefix_outfile: the prefix for the output file. Default is 'unbalance_longwas_fixed'.
     :return: A pandas data frame for the test result.
     """
@@ -64,7 +65,7 @@ def unbalance_longwas_fixed_permutation(data_file, id, tpoint, trait, bed_file,
     xmat_t = np.concatenate(xmat_t, axis=1)
     if tfix is not None:
         mat = []
-        _, dmat_t, _, _ = _design_matrix(tfix, data_df)
+        dmat_t = _design_matrix(tfix, data_df)
         for i in range(dmat_t.shape[1]):
             mat.append(xmat_t * dmat_t[:, i:(i + 1)])
         xmat_t = np.concatenate(mat, axis=1)
@@ -73,8 +74,9 @@ def unbalance_longwas_fixed_permutation(data_file, id, tpoint, trait, bed_file,
     logging.info('Time independent fixed effect: {}'.format(fix))
     xmat = xmat_t
     if fix is not None:
-        _, xmat_nt, _, _ = _design_matrix(fix, data_df)
+        xmat_nt = _design_matrix(fix, data_df)
         xmat = np.concatenate([xmat_t, xmat_nt[:, 1:]], axis=1)
+    if crank:
         _, indexes = sympy.Matrix(xmat).rref()
         xmat = xmat[:, indexes]
     logging.info('***Build the dedign matrix for random effect***')
